package com.mintegral.sdk.demo;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


import android.graphics.drawable.Drawable;
import android.text.TextUtils;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.AdapterView.OnItemSelectedListener;
import android.widget.Button;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.RatingBar;
import android.widget.Spinner;
import android.widget.TextView;

import com.google.android.gms.ads.formats.NativeAd;
import com.google.android.gms.ads.formats.NativeAppInstallAd;
import com.google.android.gms.ads.formats.NativeAppInstallAdView;
import com.google.android.gms.ads.formats.NativeContentAd;
import com.google.android.gms.ads.formats.NativeContentAdView;
import com.mintegral.msdk.MIntegralConstans;
import com.mintegral.msdk.MIntegralSDK;
import com.mintegral.msdk.out.Campaign;
import com.mintegral.msdk.out.Frame;
import com.mintegral.msdk.out.MIntegralSDKFactory;
import com.mintegral.msdk.out.MtgNativeHandler;
import com.mintegral.msdk.out.NativeListener.NativeAdListener;
import com.mintegral.msdk.out.NativeListener.NativeTrackingListener;
import com.mintegral.msdk.widget.MTGAdChoice;
import com.mintegral.sdk.demo.util.ImageLoadTask;

public class NativeActivity extends BaseActivity implements OnClickListener {
	private static final String TAG = NativeActivity.class.getName();

	private Button mBtNative;
	private Button mBtPreloadNative;
	private Spinner mSpinner;
	private static final String sMTGAdSouceUnitID = "146868";

	public int AD_NUM = 1;
	private String mCurrentUnitId = "";

	private MtgNativeHandler mNativeHandle;
	private Campaign mCampaign;
	private FrameLayout mFlAdHolder;
	private TextView mTvTitle;
	private ImageView mIvDisplayArea;

	@Override
	public int getResLayoutId() {
		return R.layout.mintegral_demo_atv_native;
	}

	@Override
	public void initView() {
		mBtPreloadNative = (Button) findViewById(R.id.btPreNative);
		mBtNative = (Button) findViewById(R.id.btNative);
		mTvTitle = (TextView) findViewById(R.id.mintegral_demo_tv_title);
		mFlAdHolder = (FrameLayout) findViewById(R.id.fl_adplaceholder);
		mSpinner = (Spinner) findViewById(R.id.mintegral_demo_native_sp);
		mIvDisplayArea = (ImageView) findViewById(R.id.mintegral_demo_iv_display_area);

	}

	@Override
	public void initData() {
		mTvTitle.setText("NATIVE");
		List<String> adSourceList = new ArrayList<String>();
		adSourceList.add("MTG");
		ArrayAdapter<String> adSouceAdapter = new ArrayAdapter<String>(this, R.layout.mintegral_demo_native_sp_display,
				R.id.mintegral_demo_tv_sp_name, adSourceList);
		adSouceAdapter.setDropDownViewResource(R.layout.mintegral_demo_sp_dropdown_adsouce);
		mSpinner.setAdapter(adSouceAdapter);
	}

	@Override
	public void setListener() {
		mTvTitle.setOnClickListener(this);
		mBtPreloadNative.setOnClickListener(this);
		mBtNative.setOnClickListener(this);
		mSpinner.setOnItemSelectedListener(new OnItemSelectedListener() {

			@Override
			public void onItemSelected(AdapterView<?> parent, View view, int position, long id) {
				setUnitId(position);
			}

			@Override
			public void onNothingSelected(AdapterView<?> parent) {

			}
		});

	}

	private void setUnitId(int position) {
		switch (position) {
			default:
				mCurrentUnitId = sMTGAdSouceUnitID;
				break;
		}
	}

	/**
	 * Populates a {@link NativeContentAdView} object with data from a given
	 * {@link NativeContentAd}.
	 *
	 * @param nativeContentAd
	 *            the object containing the ad's assets
	 * @param adView
	 *            the view to be populated
	 */
	private void populateContentAdView(NativeContentAd nativeContentAd, NativeContentAdView adView) {
		adView.setHeadlineView(adView.findViewById(R.id.contentad_headline));
		adView.setImageView(adView.findViewById(R.id.contentad_image));
		adView.setBodyView(adView.findViewById(R.id.contentad_body));
		adView.setCallToActionView(adView.findViewById(R.id.contentad_call_to_action));
		adView.setLogoView(adView.findViewById(R.id.contentad_logo));
		adView.setAdvertiserView(adView.findViewById(R.id.contentad_advertiser));

		((TextView) adView.getHeadlineView()).setText(nativeContentAd.getHeadline());
		((TextView) adView.getBodyView()).setText(nativeContentAd.getBody());
		((TextView) adView.getCallToActionView()).setText(nativeContentAd.getCallToAction());
		((TextView) adView.getAdvertiserView()).setText(nativeContentAd.getAdvertiser());

		List<NativeAd.Image> images = nativeContentAd.getImages();

		if (images != null && images.size() > 0) {
			((ImageView) adView.getImageView()).setImageDrawable(images.get(0).getDrawable());
		}

		NativeAd.Image logoImage = nativeContentAd.getLogo();

		if (logoImage != null) {
			((ImageView) adView.getLogoView()).setImageDrawable(logoImage.getDrawable());
		}

		// Assign native ad object to the native view.
		mNativeHandle.registerView(adView, mCampaign);
	}

	public void preloadNative() {

		MIntegralSDK sdk = MIntegralSDKFactory.getMIntegralSDK();
		Map<String, Object> preloadMap = new HashMap<String, Object>();
		preloadMap.put(MIntegralConstans.PROPERTIES_LAYOUT_TYPE, MIntegralConstans.LAYOUT_NATIVE);
		preloadMap.put(MIntegralConstans.PROPERTIES_UNIT_ID, mCurrentUnitId);
		preloadMap.put(MIntegralConstans.PLACEMENT_ID, "138780");

		preloadMap.put(MIntegralConstans.PROPERTIES_AD_NUM, AD_NUM);
		preloadMap.put(MIntegralConstans.PREIMAGE, true);
		sdk.preload(preloadMap);

	}

	public void loadNative() {
		Map<String, Object> properties = MtgNativeHandler.getNativeProperties("138780", mCurrentUnitId);
		properties.put(MIntegralConstans.PROPERTIES_AD_NUM, AD_NUM);
		mNativeHandle = new MtgNativeHandler(properties, this);
		mNativeHandle.setAdListener(new NativeAdListener() {

			@Override
			public void onAdLoaded(List<Campaign> campaigns, int template) {
				Log.e(TAG, "onAdLoaded");
				if (campaigns != null && campaigns.size() > 0) {
					mIvDisplayArea.setVisibility(View.GONE);
					mCampaign = campaigns.get(0);
					for (Campaign campaign : campaigns) {
						Log.i(TAG, campaign.getAppName());
					}
					fillMTGAdLayout();
					preloadNative();
				}
			}

			private void fillMTGAdLayout() {
				final View view = LayoutInflater.from(NativeActivity.this)
						.inflate(R.layout.mintegral_demo_mul_big_ad_content, null);
				final ImageView iv = (ImageView) view.findViewById(R.id.mintegral_demo_iv_image);
				if (!TextUtils.isEmpty(mCampaign.getImageUrl())) {
					new ImageLoadTask(mCampaign.getImageUrl()) {

						@Override
						public void onRecived(Drawable result) {
							iv.setImageDrawable(result);
							mNativeHandle.registerView(view, mCampaign);
						}
					}.execute();
				}
				TextView tvAppName = (TextView) view.findViewById(R.id.mintegral_demo_bt_app_name);
				MTGAdChoice mtgAdChoice = view.findViewById(R.id.mintegral_demo_native_adchoice);
				int height = mCampaign.getAdchoiceSizeHeight();
				int width = mCampaign.getAdchoiceSizeWidth();
				ViewGroup.LayoutParams layoutParams = mtgAdChoice.getLayoutParams();
				layoutParams.width =width;
				layoutParams.height=height;
				mtgAdChoice.setLayoutParams(layoutParams);
				mtgAdChoice.setCampaign(mCampaign);
				tvAppName.setText(mCampaign.getAppName());
				mFlAdHolder.removeAllViews();
				mFlAdHolder.addView(view);
			}

			@Override
			public void onAdLoadError(String message) {
				Log.e(TAG, "onAdLoadError" + message);
			}

			@Override
			public void onAdClick(Campaign campaign) {
				Log.e(TAG, "onAdClick");
			}

			@Override
			public void onAdFramesLoaded(final List<Frame> list) {

			}

			@Override
			public void onLoggingImpression(int adsourceType) {
				Log.e(TAG, "onLoggingImpression adsourceType:" + adsourceType);
			}
		});

		mNativeHandle.setTrackingListener(new NativeTrackingListener() {

			@Override
			public void onStartRedirection(Campaign campaign, String url) {
				Log.e(TAG, "onStartRedirection---");
			}

			@Override
			public void onRedirectionFailed(Campaign campaign, String url) {
				Log.e(TAG, "onRedirectionFailed---");
			}

			@Override
			public void onFinishRedirection(Campaign campaign, String url) {
				Log.e(TAG, "onFinishRedirection---"+url);
			}

			@Override
			public void onDownloadStart(Campaign campaign) {
				Log.e(TAG, "start---");
			}

			@Override
			public void onDownloadFinish(Campaign campaign) {
				Log.e(TAG, "finish---");

			}

			@Override
			public void onDownloadProgress(int progress) {
				Log.e(TAG, "progress----" + progress);
			}

			@Override
			public boolean onInterceptDefaultLoadingDialog() {
				return false;
			}

			@Override
			public void onShowLoading(Campaign campaign) {

			}

			@Override
			public void onDismissLoading(Campaign campaign) {

			}
		});
		mNativeHandle.load();
	}

	@Override
	public void onClick(View v) {
		int id = v.getId();
		switch (id) {
			case R.id.btPreNative:
				preloadNative();
				break;
			case R.id.btNative:
				loadNative();
				break;
			case R.id.mintegral_demo_tv_title:
				finish();
				break;
		}
	}

	@Override
	protected void onDestroy() {
		super.onDestroy();
		if (mNativeHandle != null) {
			mNativeHandle.release();
		}
	}

}