package com.mintegral.sdk.demo;

import android.graphics.PixelFormat;
import android.graphics.drawable.Drawable;
import android.os.Bundle;

import androidx.recyclerview.widget.DividerItemDecoration;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import android.text.TextUtils;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.ProgressBar;
import android.widget.TextView;
import android.widget.Toast;

import com.mintegral.msdk.MIntegralConstans;
import com.mintegral.msdk.MIntegralSDK;
import com.mintegral.msdk.base.entity.CampaignEx;
import com.mintegral.msdk.nativex.view.MTGMediaView;
import com.mintegral.msdk.out.Campaign;
import com.mintegral.msdk.out.Frame;
import com.mintegral.msdk.out.MIntegralSDKFactory;
import com.mintegral.msdk.out.MtgNativeHandler;
import com.mintegral.msdk.out.NativeListener;
import com.mintegral.msdk.out.OnMTGMediaViewListenerPlus;
import com.mintegral.msdk.widget.MTGAdChoice;
import com.mintegral.sdk.demo.util.ImageLoadTask;
import com.mintegral.sdk.demo.view.StarLevelLayoutView;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

import static com.mintegral.msdk.MIntegralConstans.NATIVE_VIDEO_SUPPORT;


public class NativeVideoRecycleViewActivity extends BaseActivity implements OnClickListener {

    private static final String TAG = NativeVideoRecycleViewActivity.class.getName();

    private Button mBtNative;
    private Button mBtShowVideo;
    private TextView mTvTitle;
    private ImageView mIvDisplayBg;
    private RecyclerView mRecycleView;
    private ProgressBar mProgressbar;
    private String mCurrentUnitId = "146868";
    public static final int AD_NUM =30;
    private MtgNativeHandler mNativeHandle;
    private List<Campaign> mAllDatas = new ArrayList<>();
    private boolean videoSupport = true;//support native video
    private Set<MTGMediaView> mediaViewSet = new HashSet<MTGMediaView>();
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        getWindow().setFormat(PixelFormat.TRANSPARENT);
    }

    private MTGMediaView mediaView;

    @Override
    public int getResLayoutId() {
        return R.layout.mintegral_demo_atv_nativevideo_recycleview;
    }

    @Override
    public void initView() {
        mBtNative = (Button) findViewById(R.id.mintegral_native_load);
        mBtShowVideo = (Button) findViewById(R.id.mintegral_native_showvideo);
        mTvTitle = (TextView) findViewById(R.id.mintegral_demo_tv_title);
        mIvDisplayBg = (ImageView) findViewById(R.id.mintegral_display_bg);
        mProgressbar = (ProgressBar) findViewById(R.id.mintegral_progressBar);
        mRecycleView = (RecyclerView) findViewById(R.id.mintegral_recycleview);
        RecyclerView.LayoutManager layoutManager = new LinearLayoutManager(getApplicationContext());
        mRecycleView.setLayoutManager(layoutManager);
        mRecycleView.addItemDecoration(new DividerItemDecoration(this, DividerItemDecoration.VERTICAL));
    }

    @Override
    public void initData() {
        mTvTitle.setText("Native_Video_RecycleView");
    }

    @Override
    public void setListener() {
        mTvTitle.setOnClickListener(this);
        mBtNative.setOnClickListener(this);
        mBtShowVideo.setOnClickListener(this);
    }

    private List<Object> getRecycleViewDatas(List<Campaign> campaigns) {

        ArrayList<Object> datas = new ArrayList<>();

        if (campaigns == null) {
            return datas;
        }
        int size = campaigns.size();
        int total = size * 3 + 3;
        for (int i = 2; i <= total; i++) {

            if (i % 3 == 0) {
                Campaign campaign = null;
                if (i / 3 <= size) {
                    campaign = campaigns.get(i / 3 - 1);
                }

                if (campaign != null && campaign.getType() == MIntegralConstans.AD_TYPE_MTG) {
                    datas.add(campaign);
                }
            } else {
                datas.add(i - 1);
            }
        }
        return datas;
    }

    public void preloadNative() {
        MIntegralSDK sdk = MIntegralSDKFactory.getMIntegralSDK();
        Map<String, Object> preloadMap = new HashMap<String, Object>();
        preloadMap.put(MIntegralConstans.PROPERTIES_LAYOUT_TYPE, MIntegralConstans.LAYOUT_NATIVE);
        preloadMap.put(MIntegralConstans.PROPERTIES_UNIT_ID, mCurrentUnitId);
        preloadMap.put(MIntegralConstans.PLACEMENT_ID, "138780");
        preloadMap.put(MIntegralConstans.PROPERTIES_AD_NUM, AD_NUM);
        preloadMap.put(MIntegralConstans.NATIVE_VIDEO_WIDTH, 720);
        preloadMap.put(MIntegralConstans.NATIVE_VIDEO_HEIGHT, 480);
        preloadMap.put(MIntegralConstans.NATIVE_VIDEO_SUPPORT, videoSupport);
        sdk.preload(preloadMap);
    }

    private void showLoading() {

        runOnUiThread(new Runnable() {
            @Override
            public void run() {
                mProgressbar.setVisibility(View.VISIBLE);
            }
        });

    }

    private void toastLoadSuccess() {
        runOnUiThread(new Runnable() {
            @Override
            public void run() {
                Toast.makeText(getApplicationContext(), "loadSuccess", Toast.LENGTH_LONG).show();
            }
        });

    }

    private void toastLoadFailed(final String msg) {
        runOnUiThread(new Runnable() {
            @Override
            public void run() {
                Toast.makeText(getApplicationContext(), "loadFailed:"+msg, Toast.LENGTH_LONG).show();
            }
        });

    }

    private void hideLoading() {
        runOnUiThread(new Runnable() {
            @Override
            public void run() {
                mProgressbar.setVisibility(View.GONE);
            }
        });

    }

    public void loadNative() {
        showLoading();
        Map<String, Object> properties = MtgNativeHandler.getNativeProperties("138780", mCurrentUnitId);
        properties.put(MIntegralConstans.NATIVE_VIDEO_WIDTH, 720);
        properties.put(MIntegralConstans.NATIVE_VIDEO_HEIGHT, 480);
        properties.put(NATIVE_VIDEO_SUPPORT, videoSupport);
        properties.put(MIntegralConstans.PROPERTIES_AD_NUM, AD_NUM);
        if(mNativeHandle == null){
            mNativeHandle = new MtgNativeHandler(properties, this);
            mNativeHandle.setAdListener(new NativeListener.NativeAdListener() {

                @Override
                public void onAdLoaded(List<Campaign> campaigns, int template) {
                    Log.e(TAG, "onAdLoaded");
                    hideLoading();
                    toastLoadSuccess();
                    if (campaigns != null && campaigns.size() > 0) {

                        mAllDatas = campaigns;
                    }
                    if (mAllDatas == null || mAllDatas.size() == 0) {
                        Toast.makeText(getApplicationContext(), "no load data to show", Toast.LENGTH_LONG).show();
                        return;
                    }
                    List<Object> datas = getRecycleViewDatas(mAllDatas);
                    destoryMediaView();

                    mIvDisplayBg.setVisibility(View.GONE);
                    mRecycleView.setVisibility(View.VISIBLE);
                    MyRecyclerViewAdapter adapter = new MyRecyclerViewAdapter(datas);
                    mRecycleView.setAdapter(adapter);


                    preloadNative();
                }

                @Override
                public void onAdLoadError(String message) {
                    Log.e(TAG, "onAdLoadError" + message);
                    hideLoading();
                    toastLoadFailed(message);
                }

                @Override
                public void onAdClick(Campaign campaign) {
                    Log.e(TAG, "onAdClick");
                }

                @Override
                public void onAdFramesLoaded(final List<Frame> list) {

                }

                @Override
                public void onLoggingImpression(int adsourceType) {
                    Log.e(TAG, "onLoggingImpression adsourceType:" + adsourceType);
                }

            });
            mNativeHandle.setTrackingListener(new NativeListener.NativeTrackingListener() {

                @Override
                public void onStartRedirection(Campaign campaign, String url) {
                }

                @Override
                public void onRedirectionFailed(Campaign campaign, String url) {
                }

                @Override
                public void onFinishRedirection(Campaign campaign, String url) {
                }

                @Override
                public void onDownloadStart(Campaign campaign) {
                    Log.e(TAG, "start---");
                }

                @Override
                public void onDownloadFinish(Campaign campaign) {
                    Log.e(TAG, "finish---");
                }

                @Override
                public void onDownloadProgress(int progress) {
                    Log.e(TAG, "progress----" + progress);
                }

                @Override
                public boolean onInterceptDefaultLoadingDialog() {
                    return false;
                }

                @Override
                public void onShowLoading(Campaign campaign) {
                }

                @Override
                public void onDismissLoading(Campaign campaign) {
                }
            });
        }
        mNativeHandle.load();
    }

    @Override
    public void onClick(View v) {

        switch (v.getId()) {
            case R.id.mintegral_native_load:
                preloadNative();
                break;
            case R.id.mintegral_native_showvideo:
                loadNative();
                break;
            case R.id.mintegral_demo_tv_title:
                finish();
                break;
        }

    }

    private class MyRecyclerViewAdapter extends RecyclerView.Adapter {

        public static final int VIEW_TYPE_VIDEO = 0;
        public static final int VIEW_TYPE_TXT = 1;

        private LayoutInflater mInflater;
        List<Object> mAllData = new ArrayList<>();

        public MyRecyclerViewAdapter(List<Object> datas) {

            this.mInflater = LayoutInflater.from(getApplicationContext());
            if (datas != null) {
                mAllData.addAll(datas);
            }
        }

        @Override
        public int getItemViewType(int position) {

            Object object = mAllData.get(position);
            if (object instanceof CampaignEx) {
                return VIEW_TYPE_VIDEO;
            } else if (object instanceof Integer) {
                return VIEW_TYPE_TXT;
            }
            return VIEW_TYPE_TXT;
        }

        @Override
        public RecyclerView.ViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {

            if (viewType == VIEW_TYPE_VIDEO) {

                View inflate = mInflater.inflate(R.layout.mintegral_nativevideo_recycleview_mediaview_item, parent, false);
                VideoViewHolder videoViewHolder = new VideoViewHolder(inflate);
                return videoViewHolder;

            } else {

                return new TxtHolder(mInflater.inflate(R.layout.mintegral_nativevideo_recycleview_item_txt, parent, false));
            }
        }

        @Override
        public void onBindViewHolder(RecyclerView.ViewHolder holder, int position) {

            Object object = mAllData.get(position);
            if (holder.getItemViewType() == VIEW_TYPE_VIDEO) {

                if (object instanceof CampaignEx) {
                    Campaign campaign = (Campaign) object;
                    VideoViewHolder videoHolder = (VideoViewHolder) holder;

                    if (videoHolder.mMediaview != null) {
                        videoHolder.mMediaview.setOnMediaViewListener(new OnMTGMediaViewListenerPlus() {
                            @Override
                            public void onEnterFullscreen() {
                                Log.e(TAG, "onEnterFullscreen");
                            }

                            @Override
                            public void onExitFullscreen() {
                                Log.e(TAG, "onExitFullscreen");
                            }

                            @Override
                            public void onStartRedirection(Campaign campaign, String url) {
                                Log.e(TAG, "onStartRedirection");
                            }

                            @Override
                            public void onFinishRedirection(Campaign campaign, String url) {
                                Log.e(TAG, "onFinishRedirection");
                            }

                            @Override
                            public void onRedirectionFailed(Campaign campaign, String url) {
                                Log.e(TAG, "onRedirectionFailed");
                            }

                            @Override
                            public void onVideoAdClicked(Campaign campaign) {
                                Log.e(TAG, "onVideoAdClicked id:" + campaign.getId());
                            }

                            @Override
                            public void onVideoStart() {
                                Log.e(TAG, "onVideoStart");
                            }

                            @Override
                            public void onVideoComplete() {
                                Log.e(TAG, "onVideoComplete");
                            }
                        });
                    }

                    videoHolder.bindView(campaign);
                    if (videoHolder.mMediaview != null) {
                        videoHolder.mMediaview.setIsAllowFullScreen(true);
                    }

                }

            } else {
                TxtHolder txtHolder = (TxtHolder) holder;
                if (object instanceof Integer) {
                    int txt = (int) object;
                    txtHolder.setText(txt + "");
                }
            }
        }

        @Override
        public int getItemCount() {
            return mAllData == null ? 0 : mAllData.size();
        }

        private class VideoViewHolder extends RecyclerView.ViewHolder {

            private MTGMediaView mMediaview;
            private ImageView mIvIcon;
            private TextView mTvAppName;
            private TextView mTvAppDesc;
            private TextView mTvCta;
            private MTGAdChoice adChoice;
            private StarLevelLayoutView mStarLayout;

            public VideoViewHolder(View itemView) {
                super(itemView);
                mMediaview = (MTGMediaView) itemView.findViewById(R.id.mintegral_mediaview);
                if(mediaViewSet != null){
                    mMediaview.setProgressVisibility(true);
                    mMediaview.setSoundIndicatorVisibility(true);
                    mMediaview.setVideoSoundOnOff(false);
                    mMediaview.setFullScreenViewBackgroundColor(0xFFCD5C5C);
                    mMediaview.setFollowActivityOrientation(false);
                    mediaViewSet.add(mMediaview);
                }
                mIvIcon = (ImageView) itemView.findViewById(R.id.mintegral_feeds_icon);
                mTvAppName = (TextView) itemView.findViewById(R.id.mintegral_feeds_app_name);
                mTvCta = (TextView) itemView.findViewById(R.id.mintegral_feeds_tv_cta);
                mTvAppDesc = (TextView) itemView.findViewById(R.id.mintegral_feeds_app_desc);
                mStarLayout = (StarLevelLayoutView) itemView.findViewById(R.id.mintegral_feeds_star);
                adChoice = itemView.findViewById(R.id.mintegral_mediaview_adchoice);
            }

            public void bindView(Campaign campaign) {
                mMediaview.setNativeAd(campaign);
                if (!TextUtils.isEmpty(campaign.getIconUrl())) {
                    new ImageLoadTask(campaign.getIconUrl()) {

                        @Override
                        public void onRecived(Drawable result) {
                            mIvIcon.setImageDrawable(result);
                        }
                    }.execute();
                }
                mTvAppName.setText(campaign.getAppName() + "");
                mTvAppDesc.setText(campaign.getAppDesc() + "");
                mTvCta.setText(campaign.getAdCall());
                int rating = (int) campaign.getRating();
                mStarLayout.setRating(rating);
                adChoice.setCampaign(campaign);
                mNativeHandle.registerView(itemView, campaign);
            }
        }

        private class TxtHolder extends RecyclerView.ViewHolder {

            private TextView mTvDesc;

            public TxtHolder(View itemView) {
                super(itemView);
                mTvDesc = (TextView) itemView.findViewById(R.id.mintegral_tv_recycleview_desc);
            }

            public void setText(String txt) {
                mTvDesc.setText(txt);
            }
        }
    }

    private void destoryMediaView(){
        if(mediaViewSet != null && mediaViewSet.size() > 0){
            for(MTGMediaView mediaview : mediaViewSet){
                mediaview.destory();
            }
        }
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        if (mNativeHandle != null) {
            mNativeHandle.release();
        }
        destoryMediaView();
    }

}
